GET DATA /TYPE=XLS
   /FILE="Copy of moderators.26Oct08.xls"
   /SHEET=name 'Combined'
   /CELLRANGE= range 'A1:AL650'
   /READNAMES=on
   /ASSUMEDSTRWIDTH=32767 .

SORT CASES BY paper_num expt_num sample_num 
   crit_code criterion_content iat_code iat_content self_rep_code self_report_content .

*CROSSTABS crit_code BY category .

FREQUENCIES report_year pub_stat ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess 
  i_sd e_sd control ib_corr eb_corr comp iat_type iat_code self_rep_code .
DESCRIPTIVES ALL .

*Note: There is one aberrant case of ipo=4 (fix it).

MISSING VALUES 
 r_icc r_ecc (-2)
 ms_log (-2, 3)
 wor_pic (-2, 2)
 ipo epo bpo (0, -2, 4)
 i_b_pos e_b_pos (0, -2)
 i_sess e_sess (-2, 2)
 i_sd e_sd ib_corr eb_corr comp iat_type (-2)
 iat_code self_rep_code ("X") .

*Check missing value identifications .
FREQUENCIES report_year pub_stat ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess 
  i_sd e_sd control ib_corr eb_corr comp iat_type iat_code self_rep_code .
DESCRIPTIVES ALL .


VALUE LABELS category
 "A" "race"
 "B" "ethnicity etc."
 "C" "gender-sex"
 "D" "food or drink"
 "E" "other consumer prefs"
 "F" "political prefs"
 "G" "drugs or tobacco"
 "H" "self-esteem"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

*CROSSTABS criterion_content BY category .

*Define Variable Properties.
*paper_num.
FORMATS paper_num (F3.0).
VARIABLE LABELS paper_num 'Paper Number'.

*author_names.
VARIABLE LABELS author_names 'Authors'.
*FORMATS author_names (A64) .
VARIABLE WIDTH author_names (25).

*report_year.
VARIABLE LEVEL report_year  (ORDINAL).
FORMATS report_year (F4.0).
VARIABLE LABELS report_year 'Year of Report'.

*pub_stat.
VARIABLE LEVEL pub_stat  (NOMINAL).
FORMATS pub_stat (F2.0).
VARIABLE LABELS pub_stat 'publication status'.
VALUE LABELS  pub_stat
     0  'unpublished'
     1  'published'  .

*sample_num.
VARIABLE LABELS sample_num 'independent sample number'.
FORMATS sample_num (F2.0).
VARIABLE WIDTH sample_num (6).

*expt_num.
VARIABLE LABELS expt_num 'experiment number'.
FORMATS expt_num (F2.0).
VARIABLE WIDTH expt_num (3).

*crit_code.
VARIABLE LABELS crit_code 'criterion code'.
VARIABLE WIDTH crit_code (2).

*criterion_content.
VARIABLE LABELS criterion_content 'criterion content'.
*FORMATS criterion_content (A64) .
VARIABLE WIDTH criterion_content (25).

*iat_code .
VARIABLE LABELS iat_code 'IAT code'.
*FORMATS iat_code (A1) .
VARIABLE WIDTH iat_code (3).

*iat_content .
VARIABLE LABELS iat_content 'IAT content'.
*FORMATS iat_content (A64) .
VARIABLE WIDTH iat_content (25).

*self_rep_code .
VARIABLE LABELS self_rep_code 'Self-report code'.
*FORMATS self_rep_code (A2) .
VARIABLE WIDTH self_rep_code (3).

*self_report_content .
VARIABLE LABELS self_report_content 'Self-report content'.
*FORMATS self_report_content (A64) .
VARIABLE WIDTH self_report_content (25).

*num_iats .
VARIABLE LABELS num_iats 'No. of IAT measures'.
FORMATS num_iats (F2.0).
VARIABLE WIDTH num_iats (3).

*r_icc .
VARIABLE LABELS r_icc 'IAT-criterion r effect size'.
FORMATS r_icc (F5.3).
VARIABLE WIDTH r_icc (5).

*r_ecc .
VARIABLE LABELS r_ecc 'self-report-criterion r effect size'.
FORMATS r_ecc (F5.3).
VARIABLE WIDTH r_ecc (5).

*N_icc .
VARIABLE LABELS N_icc 'IAT-criterion r sample size'.
FORMATS N_icc (F5.0).
VARIABLE WIDTH N_icc (5).

*N_ecc .
VARIABLE LABELS N_ecc 'self-report-criterion r sample size'.
FORMATS N_ecc (F5.0).
VARIABLE WIDTH N_ecc (5).

*i_att_bel_sc.
VARIABLE LEVEL i_att_bel_sc  (NOMINAL).
VARIABLE LABELS i_att_bel_sc 'Implicit: Attitude, Belief or Self-Concept'.
FORMATS i_att_bel_sc (F8.0).
VALUE LABELS  i_att_bel_sc
     1  'Attitude'
     2  'Belief'
     3  'Self-Concept'
     4  'Not Reported'  .

*e_att_bel_sc.
VARIABLE LEVEL e_att_bel_sc  (NOMINAL).
VARIABLE LABELS e_att_bel_sc 'Explicit: Attitude, Belief or Self-Concept'.
FORMATS e_att_bel_sc (F8.0).
VALUE LABELS  e_att_bel_sc
     1  'Attitude'
     2  'Belief'
     3  'Self-Concept'
     4  'Not Reported'  .

*ovr_meth.
VARIABLE LEVEL ovr_meth  (NOMINAL).
VARIABLE LABELS ovr_meth 'overall method of data collection'.
FORMATS ovr_meth (F8.0).
VALUE LABELS  ovr_meth
     0  'not observed'
     1  'observed'  .

*inserted here to allow on-screen display of all output .
DESCRIPTIVES paper_num .

*method.
VARIABLE LEVEL method  (NOMINAL).
VARIABLE LABELS method 'method of data collection'.
FORMATS method (F8.0).
VALUE LABELS  method
     1  'self reported past behavior'
     2  'predicted future behavior'
     3  'self reported emotional reactions'
     4  'self reported judgments'
     5  'observed behavior'
     6  'neurological responses'
     7  'other'  .

*ms_log.
VARIABLE LEVEL ms_log  (NOMINAL).
VARIABLE LABELS ms_log 'Millisecond/Log Transformed/Algorithm'.
FORMATS ms_log (F8.0).
VALUE LABELS  ms_log
     0  'Millisecond'
     1  'Log Transformed'
     2  'Algorithm'
     3  'Not Reported'  .

*wor_pic.
VARIABLE LEVEL wor_pic  (NOMINAL).
VARIABLE LABELS wor_pic 'Words/Pictures'.
FORMATS wor_pic (F8.0).
VALUE LABELS  wor_pic
     0  'Words'
     1  'Pictures'
     2  'Not Reported'  .

*num_iats.
FORMATS num_iats (F8.0).
VARIABLE LABELS num_iats 'Number of IATs in Study'.
*ipo.
VARIABLE LEVEL ipo  (ORDINAL).
VARIABLE LABELS ipo 'IAT presentation order'.
FORMATS ipo (F2.0).
VALUE LABELS  ipo
     0  'Not Reported'
     1  'IAT First'
     2  'IAT Second'
     3  'IAT Third'  .

*bpo.
VARIABLE LEVEL bpo  (ORDINAL).
VARIABLE LABELS bpo 'Behavior Position'.
FORMATS bpo (F8.0).
VALUE LABELS  bpo
     0  'Not Reported'
     1  'Behavior First'
     2  'Behavior Second'
     3  'Behavior Third'  .

*epo.
VARIABLE LEVEL epo  (ORDINAL).
VARIABLE LABELS epo 'Explicit Presentation Order'.
FORMATS epo (F8.0).
VALUE LABELS  epo
     0  'Not Reported'
     1  'Explicits First'
     2  'Explicits Second'
     3  'Explicits Third'  .

*i_b_pos.
VARIABLE LEVEL i_b_pos  (ORDINAL).
VARIABLE LABELS i_b_pos 'IAT position relative to behavior'.
FORMATS i_b_pos (F8.0).
VALUE LABELS  i_b_pos
     0  'Not Reported'
     1  'IAT Before Behavior'
     2  'IAT After Behavior'
     3  'Counterbalanced'  .

*e_b_pos.
VARIABLE LEVEL e_b_pos  (ORDINAL).
VARIABLE LABELS e_b_pos 'Explicit position relative to behavior'.
FORMATS e_b_pos (F8.0).
VALUE LABELS  e_b_pos
     0  'Not Reported'
     1  'Explicit before behavior'
     2  'Explicit after behavior'
     3  'Counterbalanced'  .

*i_sess.
VARIABLE LEVEL i_sess  (ORDINAL).
VARIABLE LABELS i_sess 'Different session code for IAT'.
FORMATS i_sess (F8.0).
VALUE LABELS  i_sess
     0  'Same session administration of IAT'
     1  'Different session administration of IAT'  .

*e_sess.
VARIABLE LEVEL e_sess  (ORDINAL).
VARIABLE LABELS e_sess 'Different session code for explicits'.
FORMATS e_sess (F8.0).
VALUE LABELS  e_sess
     0  'Same Session Administration of Explicit Measures'
     1  'Separate Session Administration of Explicit Measures'  .

*iat_type.
FORMATS iat_type (F8.0).
VARIABLE LABELS iat_type 'Single Dual or Personalized IAT'.
VALUE LABELS  iat_type
     1  'Single Category'
     2  'Dual Category'
     3  'Personalized IAT'  .

*ib_corr.
FORMATS ib_corr (F5.2).
VARIABLE LABELS ib_corr 'Correspondence between the IAT and the behavior measure'.

*eb_corr.
FORMATS eb_corr (F5.2).
VARIABLE LABELS eb_corr 'Correspondence between the explicit and behavior measure'.

*inserted here to allow on-screen display of all output .
DESCRIPTIVES paper_num .

*i_sd.
FORMATS i_sd (F5.1).
VARIABLE LABELS i_sd 'IAT social desirability rating'.

*e_sd.
FORMATS e_sd (F5.1).
VARIABLE LABELS e_sd 'Explicit social desirability rating'.

*control.
FORMATS control (F5.1).
VARIABLE LABELS control 'controllability rating'. 

*comp
FORMATS comp (F5.1).
VARIABLE LABELS comp 'Complementarity'.

*********************************** .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

SAVE OUTFILE = "UUIAT3.ICCs.ECCs.moderators.sav" .
**************************************************************************************.
GET FILE = "UUIAT3.ICCs.ECCs.moderators.sav" .
AGGREGATE OUTFILE = "iat_measures.table.sav" /
 BREAK = paper_num author_names sample_num expt_num iat_code 
 / report_year pub_stat category i_att_bel_sc num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type = FIRST 
  (report_year pub_stat category i_att_bel_sc num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type) .

AGGREGATE OUTFILE = "self_report_measures.table.sav" /
 BREAK = paper_num author_names sample_num expt_num self_rep_code  
 / report_year pub_stat category e_att_bel_sc num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type = FIRST 
  (report_year pub_stat category e_att_bel_sc num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type) .
**************************************************************************************.
