*Add Wilson Macro for Mean effect size .
INCLUDE "meanes.sps" .
INCLUDE "metaf.sps" .

***********************************************.
*ALL ICCs.
***********************************************.
*Compute aggregate ICC .
GET FILE = "UUIAT3.ICCs.ECCs.moderators.sav" .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

DESCRIPTIVES r_icc r_ecc .

COMPUTE z_icc =  0.5*(LN((1+r_icc)/(1-r_icc))) .
COMPUTE wt_icc = N_icc - 3 .
COMPUTE z_X_wt_icc = z_icc * wt_icc .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .

* Combine across attitude/stereotype/self-concept iccs within independent samples.
AGGREGATE OUTFILE = * / BREAK = paper_num sample_num expt_num category 
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) .

* Separate attitude/stereotype/self-concept iccs within independent samples.
* This may not be the preferred analysis for independent samples.
*AGGREGATE OUTFILE = * / BREAK = paper_num sample_num expt_num category i_att_bel_sc
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) .

FREQUENCIES num_ICCs .
SELECT IF (num_ICCs > 0) .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
EXECUTE .

DESCRIPTIVES ALL .

*LIST CASES / VAR = paper_num sample_num expt_num mean_wt_icc mean_z_icc .

VARIABLE LABELS 
   mean_wt_icc "sample weight"
 / mean_z_icc "sample average z" .

MEANES ES = mean_z_icc /W = mean_wt_icc /PRINT IVZR.

*First model is fixed effect, 2nd is random .
METAF ES = mean_z_icc /w = mean_wt_icc /group = category /model = FE /PRINT = IVZR . 
METAF ES = mean_z_icc /w = mean_wt_icc /group = category /model = ML /PRINT = IVZR . 

*Get total number of subjects , by category.

COMPUTE N_icc = mean_wt_icc + 3.
AGGREGATE OUTFILE = *
 / BREAK = category / N_category = SUM(N_icc) / K_category = N.

COMPUTE filter$ = 1 .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES
 / BREAK = filter$ / Total_N = SUM(N_category) / Total_K = SUM(K_category) .

LIST ALL .



***********************************************.
*ALL ECCs.
***********************************************.

*Compute aggregate ECC .
GET FILE = "UUIAT3.ICCs.ECCs.moderators.sav" .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

COMPUTE z_ecc =  0.5*(LN((1+r_ecc)/(1-r_ecc))) .
COMPUTE wt_ecc = N_ecc - 3 .
COMPUTE z_X_wt_ecc = z_ecc * wt_ecc .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
* Combine across attitude/stereotype/self-concept iccs within independent samples.
AGGREGATE OUTFILE = * / BREAK = paper_num sample_num expt_num category 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) .

* Separate attitude/stereotype/self-concept iccs within independent samples.
*AGGREGATE OUTFILE = * / BREAK = paper_num sample_num expt_num category e_att_bel_sc
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) .


FREQUENCIES num_eccs .
SELECT IF (num_eccs > 0) .

COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
EXECUTE .

DESCRIPTIVES ALL .

*LIST CASES / VAR = paper_num sample_num expt_num mean_wt_ecc mean_z_ecc .

VARIABLE LABELS 
   mean_wt_ecc "sample weight"
 / mean_z_ecc "sample average z" .

MEANES ES = mean_z_ecc /W = mean_wt_ecc /PRINT IVZR.

*First model is fixed effect, 2nd is random .
METAF ES = mean_z_ecc /w = mean_wt_ecc /group = category /model = FE /PRINT = IVZR .
METAF ES = mean_z_ecc /w = mean_wt_ecc /group = category /model = ML /PRINT = IVZR .


*Get total number of subjects , by category.

COMPUTE N_ecc = mean_wt_ecc + 3.
AGGREGATE OUTFILE = *
 / BREAK = category / N_category = SUM(N_ecc) / K_category = N.

COMPUTE filter$ = 1 .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES
 / BREAK = filter$ / Total_N = SUM(N_category) / Total_K = SUM(K_category) .

LIST ALL .

***********************************************.
*ALL IECs.
***********************************************.

*Check table file if necessary .
*GET FILE = "iat_measures.table.sav" .

*Compute aggregate IEC .
GET FILE = "UUIAT3.IECs.sav" .

DESCRIPTIVES r_iec .

SORT CASES BY paper_num sample_num expt_num iat_code .
MATCH FILES FILE = * / TABLE = "iat_measures.table.sav" 
 / BY paper_num sample_num expt_num iat_code 
 / DROP =  ovr_meth TO iat_type .
EXECUTE .

DESCRIPTIVES ALL .
RENAME VARIABLES (category = iat_category) .

SORT CASES BY paper_num sample_num expt_num self_rep_code .
MATCH FILES FILE = * / TABLE = "self_report_measures.table.sav" 
 / BY paper_num sample_num expt_num self_rep_code 
 / DROP =  ovr_meth TO iat_type .
EXECUTE .

DESCRIPTIVES ALL .
RENAME VARIABLES (category = self_rep_category) .

*COMPUTE filter$ = (iat_category NE self_rep_category) .
*FREQUENCIES filter$ .
*COMPUTE filter$ = (MISSING(i_att_bel_sc) = 1) .
*FREQUENCIES filter$ .
*FILTER BY filter$ . 
*LIST paper_num sample_num expt_num iat_code self_rep_code iat_category self_rep_category .

COMPUTE z_iec =  0.5*(LN((1+r_iec)/(1-r_iec))) .
COMPUTE wt_iec = N_iec - 3 .
COMPUTE z_X_wt_iec = z_iec * wt_iec .
EXECUTE .

RENAME VARIABLES (iat_category = category) .
*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .


*NOW aggregate to produce a single average weighted effect size for each independent sample .
AGGREGATE OUTFILE = * 
 / BREAK = paper_num sample_num expt_num category
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) .

FREQUENCIES num_iecs .
SELECT IF (num_iecs > 0) .

COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

DESCRIPTIVES ALL .

*LIST CASES / VAR = paper_num sample_num expt_num mean_wt_iec mean_z_iec .

VARIABLE LABELS 
   mean_wt_iec "sample weight"
 / mean_z_iec "sample average z" .

MEANES ES = mean_z_iec /W = mean_wt_iec /PRINT IVZR.

*First model is fixed effect, 2nd is random .
METAF ES = mean_z_iec /w = mean_wt_iec /group = category /model = FE /PRINT = IVZR .
METAF ES = mean_z_iec /w = mean_wt_iec /group = category /model = ML /PRINT = IVZR .

COMPUTE N_iec = mean_wt_iec + 3.
AGGREGATE OUTFILE = *
 / BREAK = category / N_category = SUM(N_iec) / K_category = N.

COMPUTE filter$ = 1 .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES
 / BREAK = filter$ / Total_N = SUM(N_category) / Total_K = SUM(K_category) .

LIST ALL .

