*Add Wilson Macro for Mean effect size .
INCLUDE "meanes.sps" .
INCLUDE "metaf.sps" .

***********************************************.
*ALL ICC-ECC differences.
***********************************************.
*Compute aggregate ICCs and ECCs .
GET FILE = "UUIAT3.ICCs.ECCs.moderators.sav" .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

DESCRIPTIVES r_icc r_ecc .

COMPUTE z_icc =  0.5*(LN((1+r_icc)/(1-r_icc))) .
COMPUTE wt_icc = N_icc - 3 .
COMPUTE z_X_wt_icc = z_icc * wt_icc .

COMPUTE z_ecc =  0.5*(LN((1+r_ecc)/(1-r_ecc))) .
COMPUTE wt_ecc = N_ecc - 3 .
COMPUTE z_X_wt_ecc = z_ecc * wt_ecc .
EXECUTE .


*NOW aggregate to produce a single average weighted effect size for each independent sample .

* Combine across attitude/stereotype/self-concept iccs within independent samples.
AGGREGATE OUTFILE = * / BREAK = paper_num sample_num expt_num category 
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) .

FREQUENCIES num_ICCs num_ECCs .
SELECT IF ((num_ICCs > 0) & (num_ECCs > 0)) .
EXECUTE .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_diff = mean_z_ecc - mean_z_icc .
COMPUTE mean_wt_diff = MEAN(mean_wt_icc, mean_wt_ecc) .
EXECUTE .

DESCRIPTIVES ALL .

*LIST CASES / VAR = paper_num sample_num expt_num mean_wt_icc mean_z_icc .

VARIABLE LABELS 
   mean_wt_diff "sample weight"
 / mean_z_diff "sample average z_diff" .

MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.

*First model is fixed effect, 2nd is random .
METAF ES = mean_z_diff /W = mean_wt_diff /group = category /model = FE /PRINT = IVZR . 
METAF ES = mean_z_diff /W = mean_wt_diff /group = category /model = ML /PRINT = IVZR . 

*Following is because NXLOOPS = 40 was not enough for the ML model.
SHOW MXLOOPS .
SET MXLOOPS = 50 . 
METAF ES = mean_z_diff /W = mean_wt_diff /group = category /model = ML /PRINT = IVZR . 

COMPUTE filter$ = (category="A") .
FILTER BY filter$ .
*This is the test for category = "A" "race" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="B") .
FILTER BY filter$ .
*This is the test for category = "B" "other intergroup" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="C") .
FILTER BY filter$ .
*This is the test for category = "C" "gender-sex" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="D") .
FILTER BY filter$ .
*This is the test for category = "D" "consumer prefs" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="F") .
FILTER BY filter$ .
*This is the test for category = "F" "politics" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="G") .
FILTER BY filter$ .
*This is the test for category = "G" "drugs or tobacco" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="J") .
FILTER BY filter$ .
*This is the test for category = "J" "personality or self-concept" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="K") .
FILTER BY filter$ .
*This is the test for category = "K" "clinical" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="L") .
FILTER BY filter$ .
*This is the test for category = "L" "relationships" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .


*Get total number of subjects , by category.
COMPUTE N_diff = mean_wt_diff + 3.
AGGREGATE OUTFILE = *
 / BREAK = category / N_category = SUM(N_diff) / K_category = N.

COMPUTE filter$ = 1 .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES
 / BREAK = filter$ / Total_N = SUM(N_category) / Total_K = SUM(K_category) .

LIST ALL .

