***********************************************.
*IMPORTANT NOTE:  The lines in this file that use the MeanES.sps macro 
* should **not** be changed if it is desired to use the output
* to reproduce the analysis used
* to create Figures 1 and 2.  These were done by exporting all *visible*
* output to a Word .doc, then copying that Word .doc into Figues.xls,
* which has been set up to automatically read the data for figures 
* after conversion of text to columns (Data menu on spreadsheet).
***********************************************.
* GET file with ICCS, ECCs, and IECs, by independent samples.
***********************************************.

GET FILE = "All_ESs.sav" .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num iat_code self_rep_code crit_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_bel_v_self is used as possible BREAK variable and predictor .
IF (e_att_bel_sc <= 2) e_att_bel_v_self = 1 .
IF (e_att_bel_sc = 3) e_att_bel_v_self = 0 .
*i_att_bel_v_self is used as possible BREAK variable and predictor .
IF (i_att_bel_sc <= 2) i_att_bel_v_self = 1 .
IF (i_att_bel_sc = 3) i_att_bel_v_self = 0 .

VARIABLE LABELS i_att_bel_v_self "attitude/stereotype vs. self-concept" .
VALUE LABELS i_att_bel_v_self 0 "IAT measure is self-concept" 
  1  "IAT measure is att or stereo" .

VARIABLE LABELS e_att_bel_v_self "attitude/stereotype vs. self-concept" .
VALUE LABELS e_att_bel_v_self 0 "expl measure is self-concept"
  1  "expl measure is att or stereo" .

FREQUENCIES i_att_bel_v_self e_att_bel_v_self .


AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / report_year pub_stat category = FIRST(report_year pub_stat category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_bel_v_self e_att_bel_v_self = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_bel_v_self e_att_bel_v_self) .

FREQUENCIES num_ICCs .
SELECT IF (num_ICCs > 0) .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .

FREQUENCIES category .

*Compute incremental prediction results as partial correlations .
* First reduce file to independent samples with all three types of correlation.

COMPUTE filter$ = ((MISSING(mean_z_icc)=0) & (MISSING(mean_z_ecc)=0) & (MISSING(mean_z_iec)=0)) . 
FREQUENCIES filter$ .

*Convert Zs back to r values.
COMPUTE r_IC = (EXP(2*mean_z_icc) - 1)/(EXP(2*mean_z_icc) + 1) .
COMPUTE r_EC = (EXP(2*mean_z_ecc) - 1)/(EXP(2*mean_z_ecc) + 1) .
COMPUTE r_IE = (EXP(2*mean_z_iec) - 1)/(EXP(2*mean_z_iec) + 1) .
EXECUTE .

FILTER BY filter$ .

* Compute partial correlations adapting the standard formula.
* Formula: r_12.3 = (r_12 - r_13*r_23) / sqrt((1-r_13**2)*(1-r_23**2)) .
COMPUTE r_IC.E = (r_IC - r_IE*r_EC) / sqrt((1-r_IE**2)*(1-r_EC**2)) .
COMPUTE r_EC.I = (r_EC - r_IE*r_IC) / sqrt((1-r_IE**2)*(1-r_IC**2)) .

*Convert partial rs to Zs .
COMPUTE Z_r_IC.E = 0.5*(LN((1+r_IC.E) / (1-r_IC.E))) .
COMPUTE Z_r_EC.I = 0.5*(LN((1+r_EC.I) / (1-r_EC.I))) .
EXECUTE .

COMPUTE mean_z_diff = Z_r_EC.I - Z_r_IC.E .
COMPUTE mean_wt_diff = MEAN(mean_wt_icc, mean_wt_ecc) .
VARIABLE LABELS 
   mean_wt_diff "sample weight"
 / mean_z_diff "sample difference" .
EXECUTE .

DESCRIPTIVES r_IC r_EC r_IE r_IC.E r_EC.I Z_r_IC.E Z_r_EC.I .
DESCRIPTIVES mean_wt_icc mean_wt_ecc mean_wt_iec mean_z_diff mean_wt_diff . 


**************************************************************************************** .
*   Apply weighted regression method described by Lipsey & Wilson (2001) on p. 139 .
*  Correlation matrix produced as output of wtd regr contains weighted correlations .
**************************************************************************************** .

Include MeanES.sps .
Include MetaF.sps .

MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.

*First model is fixed effect, 2nd is mixed .
METAF ES = mean_z_diff /W = mean_wt_diff /group = category /model = FE /PRINT = IVZR . 
METAF ES = mean_z_diff /W = mean_wt_diff /group = category /model = ML /PRINT = IVZR . 

COMPUTE filter$ = (category="A") .
FILTER BY filter$ .
*This is the test for category = "A" "race" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="B") .
FILTER BY filter$ .
*This is the test for category = "B" "other intergroup" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="C") .
FILTER BY filter$ .
*This is the test for category = "C" "gender-sex" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="D") .
FILTER BY filter$ .
*This is the test for category = "D" "consumer prefs" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="F") .
FILTER BY filter$ .
*This is the test for category = "F" "politics" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="G") .
FILTER BY filter$ .
*This is the test for category = "G" "drugs or tobacco" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="J") .
FILTER BY filter$ .
*This is the test for category = "J" "personality or self-concept" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="K") .
FILTER BY filter$ .
*This is the test for category = "K" "clinical" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .

COMPUTE filter$ = (category="L") .
FILTER BY filter$ .
*This is the test for category = "L" "relationships" .
MEANES ES = mean_z_diff /W = mean_wt_diff /PRINT IVZR.
FILTER OFF .


*Get total number of subjects , by category.
COMPUTE N_diff = mean_wt_diff + 3.
AGGREGATE OUTFILE = *
 / BREAK = category / N_category = SUM(N_diff) / K_category = N.

COMPUTE filter$ = 1 .
AGGREGATE OUTFILE = * MODE = ADDVARIABLES
 / BREAK = filter$ / Total_N = SUM(N_category) / Total_K = SUM(K_category) .

LIST ALL .
