****************************************************************** .
GET FILE = "All_ESs.sav" .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_vs_other is used as possible BREAK variable and predictor .
IF (e_att_bel_sc = 1) e_att_vs_other = 1 .
IF (e_att_bel_sc >=2) e_att_vs_other = 0 .
*i_att_vs_other is used as possible BREAK variable and predictor .
IF (i_att_bel_sc = 1) i_att_vs_other = 1 .
IF (i_att_bel_sc >= 2) i_att_vs_other = 0 .

VARIABLE LABELS i_att_vs_other "attitude vs. other" .
VALUE LABELS i_att_vs_other 0 "IAT is not attitude measure" 
  1  "IAT is attitude measure" .

VARIABLE LABELS e_att_vs_other "attitude vs. other" .
VALUE LABELS e_att_vs_other 0 "expl is not attitude measure" 
  1 "expl is attitude measure" .
FREQUENCIES i_att_bel_sc e_att_bel_sc .
FREQUENCIES i_att_vs_other e_att_vs_other  .

AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / report_year pub_stat category = FIRST(report_year pub_stat category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other) .

FREQUENCIES num_ECCs .
SELECT IF (num_ECCs > 0) .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .


**************************************************************************************** .
* Here starts the weighted regression of ECCs
*  as described by Lipsey & Wilson (2001) on p. 139 .
**************************************************************************************** .
Include "MetaReg.sps" .

*Strategy:  Do all regressions both as /model=FE and /model=MM .

*1. Test with all conceptual mediators .
METAREG ES=mean_z_ecc /W=mean_wt_ecc
  /IVS=mean_z_iec e_att_vs_other e_sd eb_corr control comp /MODEL=FE . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=mean_z_iec e_att_vs_other e_sd eb_corr control comp /MODEL=MM . 

*1a. Repeat without IEC as predictor .
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=e_att_vs_other e_sd eb_corr control comp /MODEL=MM . 

*1b. Repeat with control * e_sd as predictor .
** This shows nothing.
COMPUTE product = control * e_sd .
EXECUTE .
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=e_att_vs_other e_sd eb_corr control comp product /MODEL=MM . 

*1c. Repeat #1 (mixed model), dropping out complementarity .
** This improves significance of correspondence as a predictor (from .002 to .0002).
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=mean_z_iec e_att_vs_other e_sd eb_corr control /MODEL=MM . 

*1d. Repeat #1(mixed) again, this time without either complementarity or IEC .
** This doesn't affect correspondence, but makes controllability a weak (p=.03) positive effect.
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=e_att_vs_other e_sd eb_corr control /MODEL=MM . 

*1e. Repeat #1 (mixed) without political preferences topic (category = F) .
COMPUTE filter$ = (category ne "F") .
FILTER BY filter$ .
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=mean_z_iec e_att_vs_other e_sd eb_corr control comp /MODEL=MM . 
FILTER OFF .


*2. Test with each predictor by itself (univariate).
*2a. mean_z_iec .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=mean_z_iec /MODEL=FE . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=mean_z_iec /MODEL=MM . 

*2b. e_att_vs_other .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=e_att_vs_other  /MODEL=MM . 

*2c. e_sd  .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=e_sd   /MODEL=MM . 

*2d. eb_corr  .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=eb_corr   /MODEL=MM . 

*2e. control  .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=control   /MODEL=MM . 

*2f. comp  .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=comp   /MODEL=MM . 

*2g. Univariate significant effects found in mixed model for: .
*  mean_z_iec e_sd eb_corr comp .
* Repeat with just these as predictors .
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=mean_z_iec e_sd eb_corr comp /MODEL=FE . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc /IVS=mean_z_iec e_sd eb_corr comp /MODEL=MM . 
* This leaves 3 effects mean_z_iec (10**-7), e_sd (10**-5), and comp (.0004) as significant predictors .

*2h. Compute correlations among conceptual moderators using SPSS weighted regression.
*  Note this produces weighted correlations among the variables .
REGRESSION / REGWGT = mean_wt_ecc / DESCRIPTIVES = CORR 
 / DEP = mean_z_ecc
 / METHOD = ENTER mean_z_iec e_att_vs_other e_sd control eb_corr comp . 

*2i. Do the same with unweighted regression, just to see how it's different.
REGRESSION / DESCRIPTIVES = CORR / STATISTICS = R CHA COEFF ANOVA ZPP 
 / DEP = mean_z_ecc
 / METHOD = ENTER mean_z_iec e_att_vs_other e_sd control eb_corr comp . 

DESCRIPTIVES mean_z_iec e_att_vs_other e_sd control eb_corr . 

*************  Analyses of Method Moderators ************** .
* report_year pub_stat ovr_meth method epo e_b_pos e_sess .

FREQUENCIES method .
*Ignore "method" because of lack of rational way to analyze it (other than as dummy codes).

*"ovr_meth", "wor_pic", and "e_sess" are usable binary variables .

*"e_b_pos" should be recoded to interchange values of 2 and 3, so "counterbalanced" is intermediate. 
RECODE e_b_pos (2=3) (3=2) .
COMPUTE ecc_sample_size = mean_wt_ecc + 3 .
EXECUTE .

*3a. Test with all method predictors (include only "i" predictors for eccs . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc
  /IVS=num_eccs ecc_sample_size ovr_meth e_b_pos e_sess report_year pub_stat  /MODEL=FE . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=num_eccs ecc_sample_size ovr_meth e_b_pos e_sess report_year pub_stat  /MODEL=MM . 

*No effects significant in MM analysis, 2 effects weakly significant in FE model.
*3b. Rerun with just those two (report_year and ovr_meth) . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc
  /IVS=report_year ovr_meth /MODEL=FE . 
METAREG ES=mean_z_ecc /W=mean_wt_ecc 
  /IVS=report_year ovr_meth /MODEL=MM . 
*ovr_meth is significant with mixed model.

*4. Re-run with predictors one at a time (univariate).
*4c. num_eccs .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=num_eccs /MODEL=MM . 

*4d. ecc_sample_size .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=ecc_sample_size /MODEL=MM . 

*4e. ovr_meth .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=ovr_meth /MODEL=MM . 
* This is significant (larger effects with reported than with observed behavior) .

*4f. e_b_pos .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=e_b_pos /MODEL=MM . 

*4g e_sess .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=e_sess /MODEL=MM . 

*4a. report_year.
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=report_year  /MODEL=MM . 

*4b. pub_stat .
METAREG ES=mean_z_ecc /W=mean_wt_ecc  /IVS=pub_stat /MODEL=MM . 

*4h Compute weighted correlations among method moderators using SPSS weighted regression.
REGRESSION / REGWGT = mean_wt_ecc  / DESCRIPTIVES = CORR
 / DEP = mean_z_ecc
 / METHOD = ENTER num_eccs ecc_sample_size ovr_meth e_b_pos e_sess report_year pub_stat . 

DESCRIPTIVES num_eccs ecc_sample_size ovr_meth e_b_pos e_sess report_year pub_stat . 
