****************************************************************** .
GET FILE = "All_ESs.sav" .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_vs_other is used as possible BREAK variable and predictor .
IF (e_att_bel_sc = 1) e_att_vs_other = 1 .
IF (e_att_bel_sc >=2) e_att_vs_other = 0 .
*i_att_vs_other is used as possible BREAK variable and predictor .
IF (i_att_bel_sc = 1) i_att_vs_other = 1 .
IF (i_att_bel_sc >= 2) i_att_vs_other = 0 .

VARIABLE LABELS i_att_vs_other "attitude vs. other" .
VALUE LABELS i_att_vs_other 0 "IAT is not attitude measure" 
  1  "IAT is attitude measure" .

VARIABLE LABELS e_att_vs_other "attitude vs. other" .
VALUE LABELS e_att_vs_other 0 "expl is not attitude measure" 
  1 "expl is attitude measure" .
FREQUENCIES i_att_bel_sc e_att_bel_sc .
FREQUENCIES i_att_vs_other e_att_vs_other  .

AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / category = FIRST(category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / report_year pub_stat num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other = MEAN 
  (report_year pub_stat num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other) .

FREQUENCIES num_ECCs .
SELECT IF (num_ECCs > 0) .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .


**************************************************************************************** .
* Here starts the weighted regression of IECs
*  as described by Lipsey & Wilson (2001) on p. 139 .
* Except for the first analysis, nly mixed models are tested .
************************************************************************************* .
Include "MetaReg.sps" .

*Compute averaged moderators for the 3 types done for both "i" and "e" .
COMPUTE ie_sd = MEAN(i_sd, e_sd) .
COMPUTE ieb_corr = MEAN(ib_corr, eb_corr) .
COMPUTE ie_att_vs_other = MEAN(i_att_vs_other, e_att_vs_other) . 
EXECUTE .

*1. Compute weighted correlations among conceptual moderators using SPSS weighted regression.
DESCRIPTIVES i_att_vs_other e_att_vs_other ie_sd ieb_corr control comp .
REGRESSION / REGWGT = mean_wt_iec  / DESCRIPTIVES = CORR
 / DEP = mean_z_iec
 / METHOD = ENTER i_att_vs_other e_att_vs_other ie_sd ieb_corr control comp . 

*1i. Test with all conceptual "i" mediators .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_att_vs_other i_sd ib_corr control comp /MODEL=FE . 
METAREG ES=mean_z_iec /W=mean_wt_iec 
  /IVS=i_att_vs_other i_sd ib_corr control comp /MODEL=MM . 

*1e. Test with all conceptual "e" mediators .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=e_att_vs_other e_sd eb_corr control comp /MODEL=FE . 
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=e_att_vs_other e_sd eb_corr control comp /MODEL=MM . 

*1i+e.  Test with all conceptual mediators (both "i" and "e").
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_att_vs_other e_att_vs_other i_sd e_sd ib_corr eb_corr control comp /MODEL=MM . 

*1ie-a.  Test with averaged conceptual mediators ("ie").
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=ie_att_vs_other ie_sd ieb_corr control comp /MODEL=MM . 

*Conclusion from above is that i_att_vs_other and e_att_vs_other should be
* kept separate, otherwise the two parallel i and e measures should be averaged.

*1ie-b.  Test with averaged conceptual mediators ("ie").
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_att_vs_other e_att_vs_other ie_sd ieb_corr control comp /MODEL=MM . 

*1ie-c. Repeat #1ie-b (mixed model), dropping out complementarity .
** This has the effect of making controllability a significant moderator (p = .02).
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_att_vs_other e_att_vs_other ie_sd ieb_corr control /MODEL=MM . 


*2. Test with each predictor by itself (univariate).
*2ae.  e_att_vs_other .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=e_att_vs_other  /MODEL=MM . 
*2ai.  i_att_vs_other .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=i_att_vs_other  /MODEL=MM . 

*2be. e_sd  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=e_sd   /MODEL=MM . 
*2bi. i_sd  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=i_sd   /MODEL=MM . 
*2bie. ie_sd .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=ie_sd   /MODEL=MM . 

*2ce. eb_corr  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=eb_corr /MODEL=MM . 
*2ci. ib_corr  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=ib_corr /MODEL=MM . 
*2cie. ieb_corr  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=ieb_corr /MODEL=MM . 

*2d. control  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=control /MODEL=MM . 

*2e. comp  .
METAREG ES=mean_z_iec /W=mean_wt_iec /IVS=comp /MODEL=MM . 


*************  Analyses of Method Moderators ************** .
* report_year pub_stat ovr_meth method epo e_b_pos e_sess .

FREQUENCIES method .
*Ignore "method" because of lack of rational way to analyze it (other than as dummy codes).

*"ovr_meth", "wor_pic", and "e_sess" are usable binary variables .

*"i_b_pos" and "e_b_pos" should be recoded to interchange values of 2 and 3, 
* so "counterbalanced" is intermediate .
RECODE i_b_pos e_b_pos (2=3) (3=2) .
COMPUTE iec_sample_size = mean_wt_iec + 3 .
EXECUTE .

*3. Compute weighted correlations among method moderators using SPSS weighted regression.

DESCRIPTIVES report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats ms_log wor_pic 
           ipo i_b_pos i_sess epo e_b_pos e_sess .

REGRESSION / REGWGT = mean_wt_iec  / DESCRIPTIVES = CORR
 / DEP = mean_z_iec
 / METHOD = ENTER report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats ms_log wor_pic 
           ipo i_b_pos i_sess epo e_b_pos e_sess . 
*Repeat dropping ms_log and wor_pic, which cause loss of cases .
REGRESSION / REGWGT = mean_wt_iec  / DESCRIPTIVES = CORR
 / DEP = mean_z_iec
 / METHOD = ENTER report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats 
           ipo i_b_pos i_sess epo e_b_pos e_sess . 


*3a. Test with all method predictors . 
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats ms_log wor_pic 
       ipo i_b_pos i_sess epo e_b_pos e_sess /MODEL=FE . 
METAREG ES=mean_z_iec /W=mean_wt_iec 
  /IVS=report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats ms_log wor_pic 
       ipo i_b_pos i_sess epo e_b_pos e_sess /MODEL=MM . 

*3b. dropping ms_log and wor_pic, which cause loss of cases .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=report_year pub_stat num_iecs iec_sample_size ovr_meth num_iats 
       ipo i_b_pos i_sess epo e_b_pos e_sess /MODEL=FE . 
METAREG ES=mean_z_iec /W=mean_wt_iec 
  /IVS=report_year pub_stat ovr_meth num_iecs iec_sample_size num_iats  
       ipo i_b_pos i_sess epo e_b_pos e_sess /MODEL=MM . 
 
*Observation:  e_b_pos appears only significant predictor in simultaneous analyses .

*4. Repeat with predictors one at a time . 
*4a. report_year.
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=report_year /MODEL=MM . 

*4b. pub_stat .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=pub_stat /MODEL=MM . 

*4c. num_iecs .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=num_iecs /MODEL=MM . 

*4d.
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=iec_sample_size /MODEL=MM . 

*4e. ovr_meth .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=ovr_meth /MODEL=MM . 

*4f. num_iats .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=num_iats /MODEL=MM . 

*4g. ms_log .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=ms_log /MODEL=MM . 

*4h. wor_pic .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=wor_pic /MODEL=MM . 

*4i. ipo .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=ipo /MODEL=MM . 

*4j. i_b_pos .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_b_pos /MODEL=MM . 

*4k. i_sess .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=i_sess /MODEL=MM . 

*4l. epo .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=epo /MODEL=MM . 

*4m. e_b_pos .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=e_b_pos /MODEL=MM . 

*4n. e_sess .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=e_sess /MODEL=MM . 

*Only significant univariate effects are ipo and e_b_pos.
* e_b_pos was only significant predictor in simultaneous regr'n 
*Try them together in an analysis .
*4o. ipo + e_b_pos .
METAREG ES=mean_z_iec /W=mean_wt_iec
  /IVS=ipo e_b_pos e_sess /MODEL=MM . 
*This shows that ipo disappears as a predictor (but the multipler R is significant).
