***********************************************.
*IMPORTANT NOTE:  This file cannot be executed after running any syntax .
*that "include"s MeanES.sps and MetaF.sps.  It is necessary to close .
*SPSS entirely and restart before running this syntax. 
***********************************************.
* GET file with ICCS, ECCs, and IECs, by independent samples.
***********************************************.

****************************************************************** .
GET FILE = "All_ESs.sav" .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_vs_other is used as possible BREAK variable and predictor .
IF (e_att_bel_sc = 1) e_att_vs_other = 1 .
IF (e_att_bel_sc >=2) e_att_vs_other = 0 .
*i_att_vs_other is used as possible BREAK variable and predictor .
IF (i_att_bel_sc = 1) i_att_vs_other = 1 .
IF (i_att_bel_sc >= 2) i_att_vs_other = 0 .

VARIABLE LABELS i_att_vs_other "attitude vs. other" .
VALUE LABELS i_att_vs_other 0 "IAT is not attitude measure" 
  1  "IAT is attitude measure" .

VARIABLE LABELS e_att_vs_other "attitude vs. other" .
VALUE LABELS e_att_vs_other 0 "expl is not attitude measure" 
  1 "expl is attitude measure" .
FREQUENCIES i_att_bel_sc e_att_bel_sc .
FREQUENCIES i_att_vs_other e_att_vs_other  .


AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / report_year pub_stat category = FIRST(report_year pub_stat category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other) .

FREQUENCIES num_ICCs .
SELECT IF (num_ICCs > 0) .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .

FREQUENCIES category .

*Compute incremental prediction results as partial correlations .
* First reduce file to independent samples with all three types of correlation.

COMPUTE filter$ = ((MISSING(mean_z_icc)=0) & (MISSING(mean_z_ecc)=0) & (MISSING(mean_z_iec)=0)) . 
FREQUENCIES filter$ .

*Convert Zs back to r values.
COMPUTE r_IC = (EXP(2*mean_z_icc) - 1)/(EXP(2*mean_z_icc) + 1) .
COMPUTE r_EC = (EXP(2*mean_z_ecc) - 1)/(EXP(2*mean_z_ecc) + 1) .
COMPUTE r_IE = (EXP(2*mean_z_iec) - 1)/(EXP(2*mean_z_iec) + 1) .
EXECUTE .

FILTER BY filter$ .

* Compute partial correlations adapting the standard formula.
* Formula: r_12.3 = (r_12 - r_13*r_23) / sqrt((1-r_13**2)*(1-r_23**2)) .
COMPUTE r_IC.E = (r_IC - r_IE*r_EC) / sqrt((1-r_IE**2)*(1-r_EC**2)) .
COMPUTE r_EC.I = (r_EC - r_IE*r_IC) / sqrt((1-r_IE**2)*(1-r_IC**2)) .

*Convert partial rs to Zs .
COMPUTE Z_r_IC.E = 0.5*(LN((1+r_IC.E) / (1-r_IC.E))) .
COMPUTE Z_r_EC.I = 0.5*(LN((1+r_EC.I) / (1-r_EC.I))) .
EXECUTE .

DESCRIPTIVES r_IC r_EC r_IE r_IC.E r_EC.I Z_r_IC.E Z_r_EC.I .
DESCRIPTIVES mean_wt_icc mean_wt_ecc mean_wt_iec . 

*Separate the following into its own run, because all three macros can't be used together.

**************************************************************************************** .
*   Apply weighted regression method described by Lipsey & Wilson (2001) on p. 139 .
*  Correlation matrix produced as output of wtd regr contains weighted correlations .
**************************************************************************************** .

*First, incremental prediction by IAT measures.
INCLUDE MetaReg.sps .

METAREG ES=Z_r_IC.E /W=mean_wt_icc
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control comp /MODEL=MM . 

*Examine predictors singly.

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=mean_z_iec /MODEL=MM .

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=i_att_vs_other /MODEL=MM .

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=i_sd /MODEL=MM .

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=ib_corr /MODEL=MM .

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=comp /MODEL=MM .

MetaReg ES=Z_r_IC.E / W=mean_wt_iec  
  /IVs=control /MODEL=MM .

REGRESSION / STAT = R CHA COEFF ZPP ANOVA OUTS / REGWGT = mean_wt_iec  / DESCRIPTIVES = CORR
 / DEP = Z_r_IC.E
 / METHOD = ENTER mean_z_iec i_att_vs_other i_sd ib_corr comp control .

DESCRIPTIVES Z_r_IC.E mean_z_iec i_att_vs_other i_sd ib_corr comp control .


*Next, incremental prediction by self-report measures.
MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=mean_z_iec e_att_vs_other e_sd eb_corr comp control /MODEL=MM .

*Examine predictors singly.
MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=mean_z_iec /MODEL=MM .

MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=e_att_vs_other /MODEL=MM .

MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=e_sd /MODEL=MM .

MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=eb_corr /MODEL=MM .

MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=comp /MODEL=MM .

MetaReg ES=Z_r_EC.I / W=mean_wt_iec  
  /IVs=control /MODEL=MM .


REGRESSION / STAT = R CHA COEFF ZPP ANOVA OUTS / REGWGT = mean_wt_iec  / DESCRIPTIVES = CORR
 / DEP = Z_r_EC.I
 / METHOD = ENTER mean_z_iec e_att_vs_other e_sd eb_corr comp control .

DESCRIPTIVES Z_r_EC.I mean_z_iec e_att_vs_other e_sd eb_corr comp control .