GET DATA /TYPE=XLS
   /FILE="Copy of moderators.26Oct08.xls"
   /SHEET=name 'Combined'
   /CELLRANGE= range 'A1:AL650'
   /READNAMES=on
   /ASSUMEDSTRWIDTH=32767 .

IF (iat_code="") iat_code="X" .
IF (self_rep_code="") self_rep_code="X" .
EXECUTE .

MISSING VALUES r_icc N_icc r_ecc N_ecc report_year (-2) iat_code self_rep_code ("X") .

RECODE crit_code ("aa"="za") ("bb"="zb") ("cc"="zc") .

AUTORECODE iat_code self_rep_code crit_code 
 /INTO iatNcode self_repNcode critNcode .

*FREQUENCIES iatNcode self_repNcode critNcode .

*Define Variable Properties.
*paper_num.
FORMATS paper_num (F3.0).
VARIABLE LABELS paper_num 'Paper Number'.

*author_names.
VARIABLE LABELS author_names 'Authors'.
*FORMATS author_names (A64) .
VARIABLE WIDTH author_names (25).

*report_year.
FORMATS report_year (F5.0).
VARIABLE WIDTH report_year (4) .
VARIABLE LABELS report_year 'Year of Publication or Report'.

*pub_stat.
FORMATS pub_stat (F2.0).
VARIABLE WIDTH pub_stat (3).
VARIABLE LABELS pub_stat 'publication status'.
VALUE LABELS  pub_stat
     0  'unpublished'
     1  'published'  .

*sample_num.
VARIABLE LABELS sample_num 'independent sample number'.
FORMATS sample_num (F2.0).
VARIABLE WIDTH sample_num (6).

*expt_num.
VARIABLE LABELS expt_num 'experiment number'.
FORMATS expt_num (F2.0).
VARIABLE WIDTH expt_num (3).

*crit_code.
VARIABLE LABELS crit_code 'criterion code'.
VARIABLE WIDTH crit_code (2).

*criterion_content.
VARIABLE LABELS criterion_content 'criterion content'.
*FORMATS criterion_content (A64) .
VARIABLE WIDTH criterion_content (25).

*iat_code .
VARIABLE LABELS iat_code 'IAT code'.
*FORMATS iat_code (A1) .
VARIABLE WIDTH iat_code (3).

*iat_content .
VARIABLE LABELS iat_content 'IAT content'.
*FORMATS iat_content (A64) .
VARIABLE WIDTH iat_content (25).

*self_rep_code .
VARIABLE LABELS self_rep_code 'Self-report code'.
*FORMATS self_rep_code (A2) .
VARIABLE WIDTH self_rep_code (3).

*self_report_content .
VARIABLE LABELS self_report_content 'Self-report content'.
*FORMATS self_report_content (A64) .
VARIABLE WIDTH self_report_content (25).

*num_iats .
VARIABLE LABELS num_iats 'No. of IAT measures'.
FORMATS num_iats (F2.0).
VARIABLE WIDTH num_iats (3).

*r_icc .
VARIABLE LABELS r_icc 'IAT-criterion r effect size'.
FORMATS r_icc (F5.3).
VARIABLE WIDTH r_icc (5).

*r_ecc .
VARIABLE LABELS r_ecc 'self-report-criterion r effect size'.
FORMATS r_ecc (F5.3).
VARIABLE WIDTH r_ecc (5).

*N_icc .
VARIABLE LABELS N_icc 'IAT-criterion r sample size'.
FORMATS N_icc (F5.0).
VARIABLE WIDTH N_icc (5).

*N_ecc .
VARIABLE LABELS N_ecc 'self-report-criterion r sample size'.
FORMATS N_ecc (F5.0).
VARIABLE WIDTH N_ecc (5).

*i_att_bel_sc.
VARIABLE LEVEL i_att_bel_sc  (NOMINAL).
VARIABLE LABELS i_att_bel_sc 'Implicit: Attitude, Belief or Self-Concept'.
FORMATS i_att_bel_sc (F8.0).
VALUE LABELS  i_att_bel_sc
     1  'Attitude'
     2  'Belief'
     3  'Self-Concept'
     4  'Not Reported'  .

*e_att_bel_sc.
VARIABLE LEVEL e_att_bel_sc  (NOMINAL).
VARIABLE LABELS e_att_bel_sc 'Explicit: Attitude, Belief or Self-Concept'.
FORMATS e_att_bel_sc (F8.0).
VALUE LABELS  e_att_bel_sc
     1  'Attitude'
     2  'Belief'
     3  'Self-Concept'
     4  'Not Reported'  .

*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality/self-concept"
 "K" "clinical"
 "L" "relationships" .

*DESCRIPTIVES ALL .
FREQUENCIES report_year pub_stat sample_num expt_num crit_code iat_code self_rep_code num_iats .

******************** .

*Reduce to independent samples .
AGGREGATE OUTFILE = * /BREAK = author_names expt_num sample_num category 
 /N_icc pub_stat num_iats = FIRST(N_icc pub_stat num_iats)
 /N_crit = MAX(critNcode)
 /N_iats=MAX(iatNcode) /i_att_bel_sc=MEAN(i_att_bel_sc) /SD_i_att_bel_sc=SD(i_att_bel_sc)
 /N_self_reps=MAX(self_repNcode) /e_att_bel_sc=MEAN(e_att_bel_sc) /SD_e_att_bel_sc=SD(e_att_bel_sc) .

SORT CASES BY author_names expt_num sample_num .

STRING topic (A16) .
IF (category="A") topic="race" .
IF (category="B") topic="other intergroup" .
IF (category="C") topic="gender-sex" .
IF (category="D") topic="consumer" .
IF (category="F") topic="politics" .
IF (category="G") topic="drugs/tobacco" .
IF (category="J") topic="personality" .
IF (category="K") topic="clinical" .
IF (category="L") topic="relationships" .
EXECUTE .

VALUE LABELS N_crit N_iats N_self_reps .
FREQUENCIES N_crit N_iats N_self_reps .

*Save this for later match with aggregate effect sizes for independent samples.
SAVE OUTFILE = "Appendix_Table_1.sav" / DROP = category .
